define(["require", "exports", "../../Styling"], function (require, exports, Styling_1) {
    "use strict";
    Object.defineProperty(exports, "__esModule", { value: true });
    exports.getStyles = function (props) {
        var theme = props.theme, className = props.className, disabled = props.disabled, checked = props.checked;
        var semanticColors = theme.semanticColors;
        var pillUncheckedBackground = semanticColors.bodyBackground;
        var pillCheckedBackground = semanticColors.inputBackgroundChecked;
        var pillCheckedHoveredBackground = semanticColors.inputBackgroundCheckedHovered;
        var pillCheckedDisabledBackground = semanticColors.disabledText;
        var thumbBackground = semanticColors.inputBorderHovered;
        var thumbCheckedBackground = semanticColors.inputForegroundChecked;
        var thumbDisabledBackground = semanticColors.disabledText;
        var thumbCheckedDisabledBackground = semanticColors.disabledBackground;
        var pillBorderColor = semanticColors.inputBorder;
        var pillBorderHoveredColor = semanticColors.inputBorderHovered;
        var pillBorderDisabledColor = semanticColors.disabledText;
        var textDisabledColor = semanticColors.disabledBodyText;
        return {
            root: [
                'ms-Toggle',
                checked && 'is-checked',
                !disabled && 'is-enabled',
                disabled && 'is-disabled',
                className,
                {
                    marginBottom: '8px'
                }
            ],
            label: [
                'ms-Toggle-label',
                disabled && {
                    color: textDisabledColor,
                    selectors: (_a = {},
                        _a[Styling_1.HighContrastSelector] = {
                            color: 'GrayText'
                        },
                        _a)
                }
            ],
            container: [
                'ms-Toggle-innerContainer',
                {
                    display: 'inline-flex',
                    position: 'relative',
                }
            ],
            pill: [
                'ms-Toggle-background',
                Styling_1.getFocusStyle(theme, -3),
                {
                    fontSize: '20px',
                    lineHeight: '1em',
                    boxSizing: 'border-box',
                    position: 'relative',
                    width: '2.2em',
                    height: '1em',
                    borderRadius: '1em',
                    transition: 'all 0.1s ease',
                    borderWidth: '1px',
                    borderStyle: 'solid',
                    background: pillUncheckedBackground,
                    borderColor: pillBorderColor,
                    cursor: 'pointer',
                },
                !disabled && [
                    !checked && {
                        selectors: {
                            ':hover': [
                                {
                                    borderColor: pillBorderHoveredColor
                                }
                            ]
                        }
                    },
                    checked && [
                        {
                            background: pillCheckedBackground,
                            borderColor: 'transparent',
                        },
                        {
                            selectors: {
                                ':hover': [
                                    {
                                        backgroundColor: pillCheckedHoveredBackground,
                                        borderColor: 'transparent'
                                    }
                                ]
                            }
                        }
                    ]
                ],
                disabled && [
                    {
                        cursor: 'default'
                    },
                    !checked && [
                        {
                            borderColor: pillBorderDisabledColor
                        }
                    ],
                    checked && [
                        {
                            backgroundColor: pillCheckedDisabledBackground,
                            borderColor: 'transparent'
                        }
                    ],
                ]
            ],
            thumb: [
                'ms-Toggle-thumb',
                {
                    width: '.5em',
                    height: '.5em',
                    borderRadius: '.5em',
                    position: 'absolute',
                    top: '.2em',
                    transition: 'all 0.1s ease',
                    backgroundColor: thumbBackground,
                    /* Border is added to handle high contrast mode for Firefox */
                    borderColor: 'transparent',
                    borderWidth: '.27em',
                    borderStyle: 'solid',
                    boxSizing: 'border-box',
                    left: '.2em'
                },
                !disabled && checked && [
                    {
                        backgroundColor: thumbCheckedBackground,
                        left: '1.4em'
                    }
                ],
                disabled && [
                    !checked && [
                        {
                            backgroundColor: thumbDisabledBackground,
                            left: '.2em',
                        }
                    ],
                    checked && [
                        {
                            backgroundColor: thumbCheckedDisabledBackground,
                            left: '1.4em'
                        }
                    ]
                ]
            ],
            text: [
                'ms-Toggle-stateText',
                {
                    selectors: {
                        // Workaround: make rules more sepecific than Label rules.
                        '&&': {
                            padding: '0',
                            margin: '0 10px',
                            userSelect: 'none',
                        }
                    }
                },
                disabled && {
                    selectors: {
                        '&&': {
                            color: textDisabledColor,
                            selectors: (_b = {},
                                _b[Styling_1.HighContrastSelector] = {
                                    color: 'GrayText'
                                },
                                _b)
                        }
                    }
                }
            ]
        };
        var _a, _b;
    };
});
//# sourceMappingURL=Toggle.styles.js.map