import * as tslib_1 from "tslib";
import * as React from 'react';
import { BaseComponent, autobind, customizable } from '../../Utilities';
import { FocusZone, FocusZoneDirection } from '../../FocusZone';
import { ResizeGroup } from '../../ResizeGroup';
import { CrumbBase } from './Crumb.base';
import { classNamesFunction } from '../../Styling';
var OVERFLOW_KEY = 'overflow';
var nullFunction = function () { return null; };
var getClassNames = classNamesFunction();
var BreadcrumbBase = /** @class */ (function (_super) {
    tslib_1.__extends(BreadcrumbBase, _super);
    function BreadcrumbBase(props) {
        return _super.call(this, props) || this;
    }
    BreadcrumbBase.prototype.render = function () {
        var _a = this.props, as = _a.as, _b = _a.onReduceData, onReduceData = _b === void 0 ? this._onReduceData : _b, maxDisplayedItems = _a.maxDisplayedItems, className = _a.className, theme = _a.theme, items = _a.items, getStyles = _a.getStyles;
        var breadCrumbData = {
            props: this.props,
            renderedItems: items.slice(-maxDisplayedItems),
            renderedOverflowItems: items.slice(0, -maxDisplayedItems)
        };
        this._classNames = getClassNames(getStyles, { theme: theme, className: className });
        return (React.createElement(ResizeGroup, { as: as, className: this._classNames.root, onRenderData: this._onRenderData, onReduceData: onReduceData, data: breadCrumbData }));
    };
    BreadcrumbBase.prototype.focus = function () {
        if (this._focusZone) {
            this._focusZone.focus();
        }
    };
    BreadcrumbBase.prototype._onReduceData = function (data) {
        var renderedItems = data.renderedItems, renderedOverflowItems = data.renderedOverflowItems;
        var movedItem = renderedItems[0];
        renderedItems = renderedItems.slice(1);
        renderedOverflowItems = renderedOverflowItems.concat([movedItem]);
        if (movedItem !== undefined) {
            return tslib_1.__assign({}, data, { renderedItems: renderedItems, renderedOverflowItems: renderedOverflowItems });
        }
    };
    BreadcrumbBase.prototype._onRenderData = function (data) {
        var _a = data.props, ariaLabel = _a.ariaLabel, _b = _a.crumbAs, CrumbType = _b === void 0 ? CrumbBase : _b;
        var classNames = this._classNames;
        var renderedOverflowItems = data.renderedOverflowItems, renderedItems = data.renderedItems;
        var contextualItems = renderedOverflowItems.map(function (item, index) { return ({
            name: item.text,
            key: item.key,
            onClick: item.onClick && (function (ev) { return item.onClick(ev, item); }),
            href: item.href
        }); });
        return (React.createElement(FocusZone, { className: classNames.root, direction: FocusZoneDirection.horizontal, elementType: 'ol', componentRef: this._resolveRef('_focusZone'), role: 'navigation', "aria-label": ariaLabel },
            renderedOverflowItems && renderedOverflowItems.length !== 0 && (React.createElement(CrumbType, { key: 'overflow', iconProps: { iconName: 'More' }, menuProps: {
                    items: contextualItems,
                    directionalHint: 4 /* bottomLeftEdge */
                }, withChevron: renderedItems.length > 0 })),
            renderedItems.map(function (item, index) { return (React.createElement(CrumbType, { key: item.key, item: item, withChevron: index !== (renderedItems.length - 1) })); })));
    };
    BreadcrumbBase.defaultProps = {
        items: [],
        maxDisplayedItems: 999
    };
    tslib_1.__decorate([
        autobind
    ], BreadcrumbBase.prototype, "_onReduceData", null);
    tslib_1.__decorate([
        autobind
    ], BreadcrumbBase.prototype, "_onRenderData", null);
    BreadcrumbBase = tslib_1.__decorate([
        customizable('Breadcrumb', ['theme'])
    ], BreadcrumbBase);
    return BreadcrumbBase;
}(BaseComponent));
export { BreadcrumbBase };
//# sourceMappingURL=Breadcrumb.base.js.map