import * as tslib_1 from "tslib";
import * as React from 'react';
import { BaseComponent, autobind, customizable, getId, inputProperties, getNativeProps } from '../../Utilities';
import { Label } from '../../Label';
import { classNamesFunction } from '../../Styling';
var getClassNames = classNamesFunction();
var ToggleBase = /** @class */ (function (_super) {
    tslib_1.__extends(ToggleBase, _super);
    function ToggleBase(props) {
        var _this = _super.call(this) || this;
        _this._warnMutuallyExclusive({
            checked: 'defaultChecked'
        });
        _this.state = {
            checked: !!(props.checked || props.defaultChecked)
        };
        _this._id = props.id || getId('Toggle');
        return _this;
    }
    Object.defineProperty(ToggleBase.prototype, "checked", {
        /**
         * Gets the current checked state of the toggle.
         */
        get: function () {
            return this.state.checked;
        },
        enumerable: true,
        configurable: true
    });
    ToggleBase.prototype.componentWillReceiveProps = function (newProps) {
        if (newProps.checked !== undefined) {
            this.setState({
                checked: !!newProps.checked // convert null to false
            });
        }
    };
    ToggleBase.prototype.render = function () {
        var _a = this.props, _b = _a.as, RootType = _b === void 0 ? 'div' : _b, className = _a.className, theme = _a.theme, disabled = _a.disabled, label = _a.label, offAriaLabel = _a.offAriaLabel, offText = _a.offText, onAriaLabel = _a.onAriaLabel, onText = _a.onText, getStyles = _a.getStyles;
        var checked = this.state.checked;
        var stateText = checked ? onText : offText;
        var ariaLabel = checked ? onAriaLabel : offAriaLabel;
        var toggleNativeProps = getNativeProps(this.props, inputProperties, ['defaultChecked']);
        var classNames = getClassNames(getStyles, {
            theme: theme,
            className: className,
            disabled: disabled,
            checked: checked
        });
        return (React.createElement(RootType, { className: classNames.root },
            label && (React.createElement(Label, { htmlFor: this._id, className: classNames.label }, label)),
            React.createElement("div", { className: classNames.container },
                React.createElement("button", tslib_1.__assign({}, toggleNativeProps, { className: classNames.pill, disabled: disabled, id: this._id, type: 'button', ref: this._resolveRef('_toggleButton'), "aria-disabled": disabled, "aria-pressed": checked, "aria-label": ariaLabel, "data-is-focusable": true, onChange: this._noop, onClick: this._onClick }),
                    React.createElement("div", { className: classNames.thumb })),
                stateText && (React.createElement(Label, { htmlFor: this._id, className: classNames.text }, stateText)))));
    };
    ToggleBase.prototype.focus = function () {
        if (this._toggleButton) {
            this._toggleButton.focus();
        }
    };
    ToggleBase.prototype._onClick = function (ev) {
        var _a = this.props, disabled = _a.disabled, checkedProp = _a.checked, onChanged = _a.onChanged, onClick = _a.onClick;
        var checked = this.state.checked;
        if (!disabled) {
            // Only update the state if the user hasn't provided it.
            if (checkedProp === undefined) {
                this.setState({
                    checked: !checked
                });
            }
            if (onChanged) {
                onChanged(!checked);
            }
            if (onClick) {
                onClick(ev);
            }
        }
    };
    ToggleBase.prototype._noop = function () {
        /* no-op */
    };
    tslib_1.__decorate([
        autobind
    ], ToggleBase.prototype, "_onClick", null);
    ToggleBase = tslib_1.__decorate([
        customizable('Toggle', ['theme'])
    ], ToggleBase);
    return ToggleBase;
}(BaseComponent));
export { ToggleBase };
//# sourceMappingURL=Toggle.base.js.map